summaryrefslogtreecommitdiff
path: root/gladeui/glade-widget-adaptor.h
diff options
context:
space:
mode:
authorTristan Van Berkom <tvb@src.gnome.org>2008-09-20 23:49:05 +0000
committerTristan Van Berkom <tvb@src.gnome.org>2008-09-20 23:49:05 +0000
commita8a21709c5f2002eafce9ca05a2ce83c98fee583 (patch)
treec88829d78500132d7948bb0c08db1d9707c524b8 /gladeui/glade-widget-adaptor.h
parent83c9c86f797d64935a36b0e3281b14f456666c4d (diff)
downloadglade-a8a21709c5f2002eafce9ca05a2ce83c98fee583.tar.gz
Added "supports" catalog element to supply supported formats, added
* gladeui/glade-xml-utils.h, gladeui/glade-catalog.[ch], gladeui/glade-widget-adaptor.[ch], gladeui/glade-property-class.[ch], gladeui/glade-project.c, glade-palette-item.c: Added "supports" catalog element to supply supported formats, added libglade-only and libglade-unsupported properties for widget classes and property classes, those metadata will show up in the editor like versioning info, in the verify logs as well, and the palette will adjust sensitivity according to the new properties. * plugins/gtk+/gtk+.xml.in, plugins/gnome/gnome.xml.in: Added supports elements and marked widgets/properties as libglade-only/libglade-unsupported in the gtk+ catalog. svn path=/trunk/; revision=1945
Diffstat (limited to 'gladeui/glade-widget-adaptor.h')
-rw-r--r--gladeui/glade-widget-adaptor.h36
1 files changed, 23 insertions, 13 deletions
diff --git a/gladeui/glade-widget-adaptor.h b/gladeui/glade-widget-adaptor.h
index 2bc8877e..dc281b4f 100644
--- a/gladeui/glade-widget-adaptor.h
+++ b/gladeui/glade-widget-adaptor.h
@@ -5,6 +5,7 @@
#include <gladeui/glade-xml-utils.h>
#include <gladeui/glade-property-class.h>
#include <gladeui/glade-editor-property.h>
+#include <gladeui/glade-catalog.h>
#include <glib-object.h>
#include <gmodule.h>
#include <gtk/gtk.h>
@@ -42,13 +43,22 @@ typedef struct _GladeWidgetAdaptorClass GladeWidgetAdaptorClass;
((obj) ? GLADE_WIDGET_ADAPTOR_GET_CLASS(obj)->deprecated : FALSE)
/**
- * GWA_BUILDER_UNSUPPORTED:
+ * GWA_LIBGLADE_UNSUPPORTED:
* @obj: A #GladeWidgetAdaptor
*
* Checks whether this widget class unsupported by GtkBuilder
*/
-#define GWA_BUILDER_UNSUPPORTED(obj) \
- ((obj) ? GLADE_WIDGET_ADAPTOR_GET_CLASS(obj)->builder_unsupported : FALSE)
+#define GWA_LIBGLADE_UNSUPPORTED(obj) \
+ ((obj) ? GLADE_WIDGET_ADAPTOR_GET_CLASS(obj)->libglade_unsupported : FALSE)
+
+/**
+ * GWA_LIBGLADE_ONLY:
+ * @obj: A #GladeWidgetAdaptor
+ *
+ * Checks whether this widget class is only supported by libglade
+ */
+#define GWA_LIBGLADE_ONLY(obj) \
+ ((obj) ? GLADE_WIDGET_ADAPTOR_GET_CLASS(obj)->libglade_only : FALSE)
/**
* GWA_VERSION_SINCE_MAJOR:
@@ -534,9 +544,12 @@ struct _GladeWidgetAdaptorClass
gboolean deprecated; /* If this widget is currently
* deprecated
*/
- gboolean builder_unsupported; /* If this widget is not supported
- * by gtkbuilder
- */
+ gboolean libglade_unsupported; /* If this widget is not supported
+ * by libglade
+ */
+ gboolean libglade_only; /* If this widget is only supported
+ * by libglade
+ */
gboolean fixed; /* If this is a GtkContainer, use free-form
* placement with drag/resize/paste at mouse...
@@ -644,12 +657,9 @@ GType glade_widget_adaptor_get_type (void) G_GNUC_CONST;
GType glade_create_reason_get_type (void) G_GNUC_CONST;
-GladeWidgetAdaptor *glade_widget_adaptor_from_catalog (GladeXmlNode *class_node,
- const gchar *catname,
- const gchar *icon_prefix,
- GModule *module,
- const gchar *domain,
- const gchar *book);
+GladeWidgetAdaptor *glade_widget_adaptor_from_catalog (GladeCatalog *catalog,
+ GladeXmlNode *class_node,
+ GModule *module);
void glade_widget_adaptor_register (GladeWidgetAdaptor *adaptor);
@@ -42,13 +43,22 @@ typedef struct _GladeWidgetAdaptorClass GladeWidgetAdaptorClass;
* @obj: A #GladeWidgetAdaptor
*
- * Checks whether this widget class unsupported by GtkBuilder
+ * Checks whether this widget class is unsupported by Libglade
*/